@@ -33,8 +33,7 @@ Usage::
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     ListAssistantAssociationsResponseTypeDef,
@@ -69,7 +68,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListAssistantAssociationsPaginator(Boto3Paginator):
+class ListAssistantAssociationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.ListAssistantAssociations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_wisdom/paginators/#listassistantassociationspaginator)
@@ -84,7 +83,7 @@ class ListAssistantAssociationsPaginator(Boto3Paginator):
         """
 
 
-class ListAssistantsPaginator(Boto3Paginator):
+class ListAssistantsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.ListAssistants)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_wisdom/paginators/#listassistantspaginator)
@@ -99,7 +98,7 @@ class ListAssistantsPaginator(Boto3Paginator):
         """
 
 
-class ListContentsPaginator(Boto3Paginator):
+class ListContentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.ListContents)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_wisdom/paginators/#listcontentspaginator)
@@ -114,7 +113,7 @@ class ListContentsPaginator(Boto3Paginator):
         """
 
 
-class ListKnowledgeBasesPaginator(Boto3Paginator):
+class ListKnowledgeBasesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.ListKnowledgeBases)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_wisdom/paginators/#listknowledgebasespaginator)
@@ -129,7 +128,7 @@ class ListKnowledgeBasesPaginator(Boto3Paginator):
         """
 
 
-class QueryAssistantPaginator(Boto3Paginator):
+class QueryAssistantPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.QueryAssistant)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_wisdom/paginators/#queryassistantpaginator)
@@ -144,7 +143,7 @@ class QueryAssistantPaginator(Boto3Paginator):
         """
 
 
-class SearchContentPaginator(Boto3Paginator):
+class SearchContentPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.SearchContent)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_wisdom/paginators/#searchcontentpaginator)
@@ -163,7 +162,7 @@ class SearchContentPaginator(Boto3Paginator):
         """
 
 
-class SearchSessionsPaginator(Boto3Paginator):
+class SearchSessionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.SearchSessions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_wisdom/paginators/#searchsessionspaginator)
